@@ -1,10 +1,11 @@
 package Class::Sniff::App;
 
+use 5.006;
 use strict;
 use warnings;
 
 use Class::Sniff;
-use Getopt::Long;
+use Getopt::Long 2.24 qw/ :config no_ignore_case /;
 use File::Find::Rule;
 use File::Spec;
 
@@ -14,11 +15,11 @@ Class::Sniff::App - C<cnsiff> support class.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
